# Python Connector for QuickBooks #

Python Connector for QuickBooks is a connectivity solution for accessing
QuickBooks Online from Python applications to read and update data. It fully
implements the Python DB API 2.0 specification. The connector is distributed
as a wheel package for Windows and Windows Server.
 
Standard SQL syntax
 
The connector fully supports the ANSI SQL standard and lets you execute
SQL statements against your QuickBooks data just like you would normally
work with relational databases. Simple queries are directly converted
to QuickBooks API calls and executed on the QuickBooks side.

## Using the connector ##

To retrieve data from a database:
 
Import the module.
 
```
import devart.quickbooks
```
 
Connect to a database using the `connect()` module method and obtain a `connection` object:
 
If you have a refresh token and know your company ID:
```
my_connection = devart.quickbooks.connect(
    CompanyId="your_company_id",
    RefreshToken="your_refresh_token"
)
```
If you don't have a refresh token or don't know your company ID:
```
dict = quickbooks.signin()
my_connection = devart.quickbooks.connect(
    CompanyId=dict["Company Id"],
    RefreshToken=dict["Refresh Token"]
)
```
 
Create a `cursor` object using the `cursor()` connection method.
 
```
my_cursor = my_connection.cursor()
```
 
Execute the SQL statement using the `execute()` cursor method.
 
```
my_cursor.execute("SELECT * FROM employees")
```
 
Retrieve the result set using one of the `fetch*()` cursor methods.
 
```
for row in my_cursor.fetchall(): 
    print(row)
```

## What's new ##

Python Connector for QuickBooks 1.0
 
* Initial release of Python Connector for QuickBooks
* Added support for Windows 32-bit and 64-bit
* Added support for Windows Server 32-bit and 64-bit
